@@ -155,32 +155,15 @@ double set_clock(time_t timeval, int allow_adj) {
 /* Calculate the difference between localtime and GMT/UT/UTC. */
 static time_t get_gmtoffset(void) {
 	static time_t retval = -1;
-	time_t dummytime = 604800;
-	struct tm *timeinfo = NULL;
 
 	/* Return saved value. */
 	if (retval != -1) {
 		return(retval);
 	}
 
-	timeinfo = localtime(&dummytime);
-	if (timeinfo == NULL) {
-		return(-1);
-	}
-	if (timeinfo->tm_hour == 0) {
-		timeinfo->tm_hour = 24;
-	}
-	retval = (timeinfo->tm_hour * 3600) + (timeinfo->tm_min * 60);
+	time(&retval);
 
-	timeinfo = gmtime(&dummytime);
-	if (timeinfo == NULL) {
-		retval = -1;
-		return(-1);
-	}
-	if (timeinfo->tm_hour == 0) {
-		timeinfo->tm_hour = 24;
-	}
-	retval -= (timeinfo->tm_hour * 3600) + (timeinfo->tm_min * 60);
+	retval -= mktime(gmtime(&retval));
 
 	if (retval < -43200) {
 		retval += 86400; 
