@@ -3,6 +3,9 @@
 #endif
 #include "win32.h"
 
+#ifdef HAVE_MATH_H
+#include <math.h>
+#endif
 #ifdef HAVE_STDINT_H
 #include <stdint.h>
 #endif
@@ -27,6 +30,9 @@
 #ifdef HAVE_LIBCONFIG
 #include <libconfig.h>
 #endif
+#ifdef HAVE_SYSLOG_H
+#include <syslog.h>
+#endif
 #ifdef HAVE_TIME_H
 #include <time.h>
 #else
@@ -66,6 +72,7 @@ static void daemonize(void) {
 
 int set_proxy(const char *shortvar, const char *var, const char *arguments, const char *value, lc_flags_t flags, void *extra) {
 	char *host = NULL, *portstr = NULL;
+	char *real_value = NULL, *end_ptr = NULL;
 	size_t hostlen = 0;
 	int port = -1;
 
@@ -74,6 +81,11 @@ int set_proxy(const char *shortvar, const char *var, const char *arguments, cons
 		return(LC_CBRET_ERROR);
 	}
 
+	real_value = strstr(value, "://");
+	if (real_value != NULL) {
+		value = real_value + 3;
+	}
+
 	hostlen = strlen(value) + 1;
 	if (hostlen == 1) {
 		fprintf(stderr, "Error: Argument required.\n");
@@ -87,6 +99,11 @@ int set_proxy(const char *shortvar, const char *var, const char *arguments, cons
 	}
 	memcpy(host, value, hostlen);
 
+	end_ptr = strchr(host, '/');
+	if (end_ptr != NULL) {
+		*end_ptr = '\0';
+	}
+
 	portstr = strchr(host, ':');
 	if (portstr != NULL) {
 		portstr[0] = '\0';
@@ -110,6 +127,7 @@ int set_proxy(const char *shortvar, const char *var, const char *arguments, cons
 
 int add_server(const char *shortvar, const char *var, const char *arguments, const char *value, lc_flags_t flags, void *extra) {
 	char *host = NULL, *portstr = NULL;
+	char *real_value = NULL, *end_ptr = NULL;
 	size_t hostlen = 0;
 	int port = -1;
 	unsigned int  timechk = 0;
@@ -119,6 +137,11 @@ int add_server(const char *shortvar, const char *var, const char *arguments, con
 		return(LC_CBRET_ERROR);
 	}
 
+	real_value = strstr(value, "://");
+	if (real_value != NULL) {
+		value = real_value + 3;
+	}
+
 	hostlen = strlen(value) + 1;
 	if (hostlen == 1) {
 		fprintf(stderr, "Error: Argument required.\n");
@@ -132,6 +155,11 @@ int add_server(const char *shortvar, const char *var, const char *arguments, con
 	}
 	memcpy(host, value, hostlen);
 
+	end_ptr = strchr(host, '/');
+	if (end_ptr != NULL) {
+		*end_ptr = '\0';
+	}
+
 	portstr = strchr(host, ':');
 	if (portstr != NULL) {
 		portstr[0] = '\0';
@@ -162,7 +190,7 @@ int add_server(const char *shortvar, const char *var, const char *arguments, con
 }
 
 int print_help(const char *shortvar, const char *var, const char *arguments, const char *value, lc_flags_t flags, void *extra) {
-	printf("Usage: htpd [-P <proxy>] [-H <host> [-H <host> [...]]]\n");
+	printf("Usage: htpd [-M max] [-m min] [-P proxy] [-H host [-H host [...]]]\n");
 	printf("   Where each `host' is in format of:\n");
 	printf("       hostname[:port]\n");
 
@@ -171,9 +199,9 @@ int print_help(const char *shortvar, const char *var, const char *arguments, con
 
 int main(int argc, char *argv[]) {
 	unsigned int totaltimeservers = 0;
-	unsigned int maxsleeptime = 43200, minsleeptime = 4096, sleeptime = minsleeptime;
-	double delta;
 	time_t newtime = 0;
+	double delta;
+	long maxsleeptime = 43200, minsleeptime = 4096, sleeptime;
 	int lc_p_ret = 0;
 
 	htp_init();
@@ -181,12 +209,16 @@ int main(int argc, char *argv[]) {
 	lc_register_callback("Host", 'H', LC_VAR_STRING, add_server, NULL);
 	lc_register_callback("ProxyHost", 'P', LC_VAR_STRING, set_proxy, NULL);
 	lc_register_callback(NULL, 'h', LC_VAR_NONE, print_help, NULL);
+	lc_register_var("MaxSleep", LC_VAR_LONG, &maxsleeptime, 'M');
+	lc_register_var("MinSleep", LC_VAR_LONG, &minsleeptime, 'm');
 	lc_p_ret = lc_process(argc, argv, "htpd", LC_CONF_SPACE, SYSCONFDIR "/htpd.conf");
 	if (lc_p_ret < 0) {
 		fprintf(stderr, "Error processing configuration information: %s.\n", lc_geterrstr());
 		return(EXIT_FAILURE);
 	}
 
+	sleeptime = minsleeptime;
+
 	totaltimeservers = timeind;
 
 	if (totaltimeservers == 0) {
@@ -196,6 +228,8 @@ int main(int argc, char *argv[]) {
 
 	daemonize();
 
+	openlog("htpd", LOG_PID, LOG_DAEMON);
+
 	while (1) {
 		newtime = htp_calctime(timeservers, totaltimeservers, http_proxy, http_proxy_port);
 
@@ -210,7 +244,8 @@ int main(int argc, char *argv[]) {
 		 *  Divide sleep time by 2   if change == 10 (check more frequently)
 		 *  Divide sleep time by 1   if change == 5  (check as frequently)
 		 */
-		sleeptime = sleeptime / (2 + ((delta * (10 - delta)) / (10*10)));
+		delta = fabs(delta);
+		sleeptime = ((double) sleeptime) / (((delta * delta) / 66.0) + 0.5);
 
 		if (sleeptime < minsleeptime) {
 			sleeptime = minsleeptime;
@@ -219,6 +254,8 @@ int main(int argc, char *argv[]) {
 			sleeptime = maxsleeptime;
 		}
 
+		syslog(LOG_INFO, "Sleeping for %li seconds.", sleeptime);
+
 		sleep(sleeptime);
 	}
 
